"""
    Nomad Broker

    Make payments, and customs declaration for orders.  # noqa: E501

    The version of the OpenAPI document: 1.2.1
    Contact: manwei@samarkand.global
    Generated by: https://openapi-generator.tech
"""


import unittest

import nomad_broker_cli
from nomad_broker_cli.api.youzan_api import YouzanApi  # noqa: E501


class TestYouzanApi(unittest.TestCase):
    """YouzanApi unit test stubs"""

    def setUp(self):
        self.api = YouzanApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_declare_order_youzan_post(self):
        """Test case for declare_order_youzan_post

        """
        pass

    def test_query_order_youzan_post(self):
        """Test case for query_order_youzan_post

        """
        pass


if __name__ == '__main__':
    unittest.main()
